# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulpcore
from pulpcore.client.pulpcore.models.task_group_response import TaskGroupResponse  # noqa: E501
from pulpcore.client.pulpcore.rest import ApiException

class TestTaskGroupResponse(unittest.TestCase):
    """TaskGroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TaskGroupResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulpcore.models.task_group_response.TaskGroupResponse()  # noqa: E501
        if include_optional :
            return TaskGroupResponse(
                pulp_href = '0', 
                description = '0', 
                all_tasks_dispatched = True, 
                waiting = 56, 
                skipped = 56, 
                running = 56, 
                completed = 56, 
                canceled = 56, 
                failed = 56, 
                canceling = 56, 
                group_progress_reports = [
                    pulpcore.client.pulpcore.models.group_progress_report_response.GroupProgressReportResponse(
                        message = '0', 
                        code = '0', 
                        total = 56, 
                        done = 56, 
                        suffix = '0', )
                    ], 
                tasks = [
                    pulpcore.client.pulpcore.models.minimal_task_response.MinimalTaskResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        state = '0', 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        worker = '0', )
                    ]
            )
        else :
            return TaskGroupResponse(
                description = '0',
                all_tasks_dispatched = True,
        )

    def testTaskGroupResponse(self):
        """Test TaskGroupResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulpcore.configuration import Configuration


class OrphansCleanup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content_hrefs': 'list[object]',
        'orphan_protection_time': 'int'
    }

    attribute_map = {
        'content_hrefs': 'content_hrefs',
        'orphan_protection_time': 'orphan_protection_time'
    }

    def __init__(self, content_hrefs=None, orphan_protection_time=0, local_vars_configuration=None):  # noqa: E501
        """OrphansCleanup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content_hrefs = None
        self._orphan_protection_time = None
        self.discriminator = None

        if content_hrefs is not None:
            self.content_hrefs = content_hrefs
        self.orphan_protection_time = orphan_protection_time

    @property
    def content_hrefs(self):
        """Gets the content_hrefs of this OrphansCleanup.  # noqa: E501

        Will delete specified content and associated Artifacts if they are orphans.  # noqa: E501

        :return: The content_hrefs of this OrphansCleanup.  # noqa: E501
        :rtype: list[object]
        """
        return self._content_hrefs

    @content_hrefs.setter
    def content_hrefs(self, content_hrefs):
        """Sets the content_hrefs of this OrphansCleanup.

        Will delete specified content and associated Artifacts if they are orphans.  # noqa: E501

        :param content_hrefs: The content_hrefs of this OrphansCleanup.  # noqa: E501
        :type: list[object]
        """

        self._content_hrefs = content_hrefs

    @property
    def orphan_protection_time(self):
        """Gets the orphan_protection_time of this OrphansCleanup.  # noqa: E501

        The time in minutes for how long Pulp will hold orphan Content and Artifacts before they become candidates for deletion by this orphan cleanup task. This should ideally be longer than your longest running task otherwise any content created during that task could be cleaned up before the task finishes. If not specified, default is used from settings which is 1440 minutes (24 hours)  # noqa: E501

        :return: The orphan_protection_time of this OrphansCleanup.  # noqa: E501
        :rtype: int
        """
        return self._orphan_protection_time

    @orphan_protection_time.setter
    def orphan_protection_time(self, orphan_protection_time):
        """Sets the orphan_protection_time of this OrphansCleanup.

        The time in minutes for how long Pulp will hold orphan Content and Artifacts before they become candidates for deletion by this orphan cleanup task. This should ideally be longer than your longest running task otherwise any content created during that task could be cleaned up before the task finishes. If not specified, default is used from settings which is 1440 minutes (24 hours)  # noqa: E501

        :param orphan_protection_time: The orphan_protection_time of this OrphansCleanup.  # noqa: E501
        :type: int
        """

        self._orphan_protection_time = orphan_protection_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrphansCleanup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrphansCleanup):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pulpcore.client.pulpcore.api.access_policies_api import AccessPoliciesApi
from pulpcore.client.pulpcore.api.artifacts_api import ArtifactsApi
from pulpcore.client.pulpcore.api.content_api import ContentApi
from pulpcore.client.pulpcore.api.contentguards_api import ContentguardsApi
from pulpcore.client.pulpcore.api.contentguards_rbac_api import ContentguardsRbacApi
from pulpcore.client.pulpcore.api.exporters_filesystem_api import ExportersFilesystemApi
from pulpcore.client.pulpcore.api.exporters_filesystem_exports_api import ExportersFilesystemExportsApi
from pulpcore.client.pulpcore.api.exporters_pulp_api import ExportersPulpApi
from pulpcore.client.pulpcore.api.exporters_pulp_exports_api import ExportersPulpExportsApi
from pulpcore.client.pulpcore.api.groups_api import GroupsApi
from pulpcore.client.pulpcore.api.groups_model_permissions_api import GroupsModelPermissionsApi
from pulpcore.client.pulpcore.api.groups_object_permissions_api import GroupsObjectPermissionsApi
from pulpcore.client.pulpcore.api.groups_users_api import GroupsUsersApi
from pulpcore.client.pulpcore.api.importers_pulp_api import ImportersPulpApi
from pulpcore.client.pulpcore.api.importers_pulp_import_check_api import ImportersPulpImportCheckApi
from pulpcore.client.pulpcore.api.importers_pulp_imports_api import ImportersPulpImportsApi
from pulpcore.client.pulpcore.api.orphans_api import OrphansApi
from pulpcore.client.pulpcore.api.orphans_cleanup_api import OrphansCleanupApi
from pulpcore.client.pulpcore.api.publications_api import PublicationsApi
from pulpcore.client.pulpcore.api.repair_api import RepairApi
from pulpcore.client.pulpcore.api.repositories_api import RepositoriesApi
from pulpcore.client.pulpcore.api.repositories_reclaim_space_api import RepositoriesReclaimSpaceApi
from pulpcore.client.pulpcore.api.repository_versions_api import RepositoryVersionsApi
from pulpcore.client.pulpcore.api.signing_services_api import SigningServicesApi
from pulpcore.client.pulpcore.api.status_api import StatusApi
from pulpcore.client.pulpcore.api.task_groups_api import TaskGroupsApi
from pulpcore.client.pulpcore.api.tasks_api import TasksApi
from pulpcore.client.pulpcore.api.uploads_api import UploadsApi
from pulpcore.client.pulpcore.api.users_api import UsersApi
from pulpcore.client.pulpcore.api.workers_api import WorkersApi



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulpcore.configuration import Configuration


class TaskGroupResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'description': 'str',
        'all_tasks_dispatched': 'bool',
        'waiting': 'int',
        'skipped': 'int',
        'running': 'int',
        'completed': 'int',
        'canceled': 'int',
        'failed': 'int',
        'canceling': 'int',
        'group_progress_reports': 'list[GroupProgressReportResponse]',
        'tasks': 'list[MinimalTaskResponse]'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'description': 'description',
        'all_tasks_dispatched': 'all_tasks_dispatched',
        'waiting': 'waiting',
        'skipped': 'skipped',
        'running': 'running',
        'completed': 'completed',
        'canceled': 'canceled',
        'failed': 'failed',
        'canceling': 'canceling',
        'group_progress_reports': 'group_progress_reports',
        'tasks': 'tasks'
    }

    def __init__(self, pulp_href=None, description=None, all_tasks_dispatched=None, waiting=None, skipped=None, running=None, completed=None, canceled=None, failed=None, canceling=None, group_progress_reports=None, tasks=None, local_vars_configuration=None):  # noqa: E501
        """TaskGroupResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._description = None
        self._all_tasks_dispatched = None
        self._waiting = None
        self._skipped = None
        self._running = None
        self._completed = None
        self._canceled = None
        self._failed = None
        self._canceling = None
        self._group_progress_reports = None
        self._tasks = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        self.description = description
        self.all_tasks_dispatched = all_tasks_dispatched
        if waiting is not None:
            self.waiting = waiting
        if skipped is not None:
            self.skipped = skipped
        if running is not None:
            self.running = running
        if completed is not None:
            self.completed = completed
        if canceled is not None:
            self.canceled = canceled
        if failed is not None:
            self.failed = failed
        if canceling is not None:
            self.canceling = canceling
        if group_progress_reports is not None:
            self.group_progress_reports = group_progress_reports
        if tasks is not None:
            self.tasks = tasks

    @property
    def pulp_href(self):
        """Gets the pulp_href of this TaskGroupResponse.  # noqa: E501


        :return: The pulp_href of this TaskGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this TaskGroupResponse.


        :param pulp_href: The pulp_href of this TaskGroupResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def description(self):
        """Gets the description of this TaskGroupResponse.  # noqa: E501

        A description of the task group.  # noqa: E501

        :return: The description of this TaskGroupResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TaskGroupResponse.

        A description of the task group.  # noqa: E501

        :param description: The description of this TaskGroupResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def all_tasks_dispatched(self):
        """Gets the all_tasks_dispatched of this TaskGroupResponse.  # noqa: E501

        Whether all tasks have been spawned for this task group.  # noqa: E501

        :return: The all_tasks_dispatched of this TaskGroupResponse.  # noqa: E501
        :rtype: bool
        """
        return self._all_tasks_dispatched

    @all_tasks_dispatched.setter
    def all_tasks_dispatched(self, all_tasks_dispatched):
        """Sets the all_tasks_dispatched of this TaskGroupResponse.

        Whether all tasks have been spawned for this task group.  # noqa: E501

        :param all_tasks_dispatched: The all_tasks_dispatched of this TaskGroupResponse.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and all_tasks_dispatched is None:  # noqa: E501
            raise ValueError("Invalid value for `all_tasks_dispatched`, must not be `None`")  # noqa: E501

        self._all_tasks_dispatched = all_tasks_dispatched

    @property
    def waiting(self):
        """Gets the waiting of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'waiting' state  # noqa: E501

        :return: The waiting of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._waiting

    @waiting.setter
    def waiting(self, waiting):
        """Sets the waiting of this TaskGroupResponse.

        Number of tasks in the 'waiting' state  # noqa: E501

        :param waiting: The waiting of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._waiting = waiting

    @property
    def skipped(self):
        """Gets the skipped of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'skipped' state  # noqa: E501

        :return: The skipped of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._skipped

    @skipped.setter
    def skipped(self, skipped):
        """Sets the skipped of this TaskGroupResponse.

        Number of tasks in the 'skipped' state  # noqa: E501

        :param skipped: The skipped of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._skipped = skipped

    @property
    def running(self):
        """Gets the running of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'running' state  # noqa: E501

        :return: The running of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this TaskGroupResponse.

        Number of tasks in the 'running' state  # noqa: E501

        :param running: The running of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._running = running

    @property
    def completed(self):
        """Gets the completed of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'completed' state  # noqa: E501

        :return: The completed of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this TaskGroupResponse.

        Number of tasks in the 'completed' state  # noqa: E501

        :param completed: The completed of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._completed = completed

    @property
    def canceled(self):
        """Gets the canceled of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'canceled' state  # noqa: E501

        :return: The canceled of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._canceled

    @canceled.setter
    def canceled(self, canceled):
        """Sets the canceled of this TaskGroupResponse.

        Number of tasks in the 'canceled' state  # noqa: E501

        :param canceled: The canceled of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._canceled = canceled

    @property
    def failed(self):
        """Gets the failed of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'failed' state  # noqa: E501

        :return: The failed of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """Sets the failed of this TaskGroupResponse.

        Number of tasks in the 'failed' state  # noqa: E501

        :param failed: The failed of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._failed = failed

    @property
    def canceling(self):
        """Gets the canceling of this TaskGroupResponse.  # noqa: E501

        Number of tasks in the 'canceling' state  # noqa: E501

        :return: The canceling of this TaskGroupResponse.  # noqa: E501
        :rtype: int
        """
        return self._canceling

    @canceling.setter
    def canceling(self, canceling):
        """Sets the canceling of this TaskGroupResponse.

        Number of tasks in the 'canceling' state  # noqa: E501

        :param canceling: The canceling of this TaskGroupResponse.  # noqa: E501
        :type: int
        """

        self._canceling = canceling

    @property
    def group_progress_reports(self):
        """Gets the group_progress_reports of this TaskGroupResponse.  # noqa: E501


        :return: The group_progress_reports of this TaskGroupResponse.  # noqa: E501
        :rtype: list[GroupProgressReportResponse]
        """
        return self._group_progress_reports

    @group_progress_reports.setter
    def group_progress_reports(self, group_progress_reports):
        """Sets the group_progress_reports of this TaskGroupResponse.


        :param group_progress_reports: The group_progress_reports of this TaskGroupResponse.  # noqa: E501
        :type: list[GroupProgressReportResponse]
        """

        self._group_progress_reports = group_progress_reports

    @property
    def tasks(self):
        """Gets the tasks of this TaskGroupResponse.  # noqa: E501


        :return: The tasks of this TaskGroupResponse.  # noqa: E501
        :rtype: list[MinimalTaskResponse]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this TaskGroupResponse.


        :param tasks: The tasks of this TaskGroupResponse.  # noqa: E501
        :type: list[MinimalTaskResponse]
        """

        self._tasks = tasks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskGroupResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TaskGroupResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulpcore.configuration import Configuration


class PulpExportResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'task': 'str',
        'exported_resources': 'list[str]',
        'params': 'object',
        'output_file_info': 'object',
        'toc_info': 'object'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'task': 'task',
        'exported_resources': 'exported_resources',
        'params': 'params',
        'output_file_info': 'output_file_info',
        'toc_info': 'toc_info'
    }

    def __init__(self, pulp_href=None, pulp_created=None, task=None, exported_resources=None, params=None, output_file_info=None, toc_info=None, local_vars_configuration=None):  # noqa: E501
        """PulpExportResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._task = None
        self._exported_resources = None
        self._params = None
        self._output_file_info = None
        self._toc_info = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.task = task
        if exported_resources is not None:
            self.exported_resources = exported_resources
        if params is not None:
            self.params = params
        if output_file_info is not None:
            self.output_file_info = output_file_info
        if toc_info is not None:
            self.toc_info = toc_info

    @property
    def pulp_href(self):
        """Gets the pulp_href of this PulpExportResponse.  # noqa: E501


        :return: The pulp_href of this PulpExportResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this PulpExportResponse.


        :param pulp_href: The pulp_href of this PulpExportResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this PulpExportResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this PulpExportResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this PulpExportResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this PulpExportResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def task(self):
        """Gets the task of this PulpExportResponse.  # noqa: E501

        A URI of the task that ran the Export.  # noqa: E501

        :return: The task of this PulpExportResponse.  # noqa: E501
        :rtype: str
        """
        return self._task

    @task.setter
    def task(self, task):
        """Sets the task of this PulpExportResponse.

        A URI of the task that ran the Export.  # noqa: E501

        :param task: The task of this PulpExportResponse.  # noqa: E501
        :type: str
        """

        self._task = task

    @property
    def exported_resources(self):
        """Gets the exported_resources of this PulpExportResponse.  # noqa: E501

        Resources that were exported.  # noqa: E501

        :return: The exported_resources of this PulpExportResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._exported_resources

    @exported_resources.setter
    def exported_resources(self, exported_resources):
        """Sets the exported_resources of this PulpExportResponse.

        Resources that were exported.  # noqa: E501

        :param exported_resources: The exported_resources of this PulpExportResponse.  # noqa: E501
        :type: list[str]
        """

        self._exported_resources = exported_resources

    @property
    def params(self):
        """Gets the params of this PulpExportResponse.  # noqa: E501

        Any additional parameters that were used to create the export.  # noqa: E501

        :return: The params of this PulpExportResponse.  # noqa: E501
        :rtype: object
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this PulpExportResponse.

        Any additional parameters that were used to create the export.  # noqa: E501

        :param params: The params of this PulpExportResponse.  # noqa: E501
        :type: object
        """

        self._params = params

    @property
    def output_file_info(self):
        """Gets the output_file_info of this PulpExportResponse.  # noqa: E501

        Dictionary of filename: sha256hash entries for export-output-file(s)  # noqa: E501

        :return: The output_file_info of this PulpExportResponse.  # noqa: E501
        :rtype: object
        """
        return self._output_file_info

    @output_file_info.setter
    def output_file_info(self, output_file_info):
        """Sets the output_file_info of this PulpExportResponse.

        Dictionary of filename: sha256hash entries for export-output-file(s)  # noqa: E501

        :param output_file_info: The output_file_info of this PulpExportResponse.  # noqa: E501
        :type: object
        """

        self._output_file_info = output_file_info

    @property
    def toc_info(self):
        """Gets the toc_info of this PulpExportResponse.  # noqa: E501

        Filename and sha256-checksum of table-of-contents for this export  # noqa: E501

        :return: The toc_info of this PulpExportResponse.  # noqa: E501
        :rtype: object
        """
        return self._toc_info

    @toc_info.setter
    def toc_info(self, toc_info):
        """Sets the toc_info of this PulpExportResponse.

        Filename and sha256-checksum of table-of-contents for this export  # noqa: E501

        :param toc_info: The toc_info of this PulpExportResponse.  # noqa: E501
        :type: object
        """

        self._toc_info = toc_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PulpExportResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PulpExportResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulpcore.configuration import Configuration


class ProgressReportResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'message': 'str',
        'code': 'str',
        'state': 'str',
        'total': 'int',
        'done': 'int',
        'suffix': 'str'
    }

    attribute_map = {
        'message': 'message',
        'code': 'code',
        'state': 'state',
        'total': 'total',
        'done': 'done',
        'suffix': 'suffix'
    }

    def __init__(self, message=None, code=None, state=None, total=None, done=None, suffix=None, local_vars_configuration=None):  # noqa: E501
        """ProgressReportResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._message = None
        self._code = None
        self._state = None
        self._total = None
        self._done = None
        self._suffix = None
        self.discriminator = None

        if message is not None:
            self.message = message
        if code is not None:
            self.code = code
        if state is not None:
            self.state = state
        if total is not None:
            self.total = total
        if done is not None:
            self.done = done
        self.suffix = suffix

    @property
    def message(self):
        """Gets the message of this ProgressReportResponse.  # noqa: E501

        The message shown to the user for the progress report.  # noqa: E501

        :return: The message of this ProgressReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ProgressReportResponse.

        The message shown to the user for the progress report.  # noqa: E501

        :param message: The message of this ProgressReportResponse.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def code(self):
        """Gets the code of this ProgressReportResponse.  # noqa: E501

        Identifies the type of progress report'.  # noqa: E501

        :return: The code of this ProgressReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ProgressReportResponse.

        Identifies the type of progress report'.  # noqa: E501

        :param code: The code of this ProgressReportResponse.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def state(self):
        """Gets the state of this ProgressReportResponse.  # noqa: E501

        The current state of the progress report. The possible values are: 'waiting', 'skipped', 'running', 'completed', 'failed', 'canceled' and 'canceling'. The default is 'waiting'.  # noqa: E501

        :return: The state of this ProgressReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ProgressReportResponse.

        The current state of the progress report. The possible values are: 'waiting', 'skipped', 'running', 'completed', 'failed', 'canceled' and 'canceling'. The default is 'waiting'.  # noqa: E501

        :param state: The state of this ProgressReportResponse.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def total(self):
        """Gets the total of this ProgressReportResponse.  # noqa: E501

        The total count of items.  # noqa: E501

        :return: The total of this ProgressReportResponse.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ProgressReportResponse.

        The total count of items.  # noqa: E501

        :param total: The total of this ProgressReportResponse.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def done(self):
        """Gets the done of this ProgressReportResponse.  # noqa: E501

        The count of items already processed. Defaults to 0.  # noqa: E501

        :return: The done of this ProgressReportResponse.  # noqa: E501
        :rtype: int
        """
        return self._done

    @done.setter
    def done(self, done):
        """Sets the done of this ProgressReportResponse.

        The count of items already processed. Defaults to 0.  # noqa: E501

        :param done: The done of this ProgressReportResponse.  # noqa: E501
        :type: int
        """

        self._done = done

    @property
    def suffix(self):
        """Gets the suffix of this ProgressReportResponse.  # noqa: E501

        The suffix to be shown with the progress report.  # noqa: E501

        :return: The suffix of this ProgressReportResponse.  # noqa: E501
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """Sets the suffix of this ProgressReportResponse.

        The suffix to be shown with the progress report.  # noqa: E501

        :param suffix: The suffix of this ProgressReportResponse.  # noqa: E501
        :type: str
        """

        self._suffix = suffix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProgressReportResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProgressReportResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulpcore.api_client import ApiClient
from pulpcore.client.pulpcore.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TasksApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete(self, task_href, **kwargs):  # noqa: E501
        """Delete a task  # noqa: E501

        A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(task_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_href: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_with_http_info(task_href, **kwargs)  # noqa: E501

    def delete_with_http_info(self, task_href, **kwargs):  # noqa: E501
        """Delete a task  # noqa: E501

        A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_with_http_info(task_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_href: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_href'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_href' is set
        if self.api_client.client_side_validation and ('task_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_href` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_href' in local_var_params:
            path_params['task_href'] = local_var_params['task_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{task_href}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List tasks  # noqa: E501

        A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str child_tasks: Foreign Key referenced by HREF
        :param str created_resources:
        :param datetime finished_at: ISO 8601 formatted dates are supported
        :param datetime finished_at__gt: Filter results where finished_at is greater than value
        :param datetime finished_at__gte: Filter results where finished_at is greater than or equal to value
        :param datetime finished_at__lt: Filter results where finished_at is less than value
        :param datetime finished_at__lte: Filter results where finished_at is less than or equal to value
        :param list[datetime] finished_at__range: Filter results where finished_at is between two comma separated values
        :param int limit: Number of results to return per page.
        :param str logging_cid:
        :param str logging_cid__contains: Filter results where logging_cid contains value
        :param str name:
        :param str name__contains: Filter results where name contains value
        :param int offset: The initial index from which to return the results.
        :param str ordering: Which field to use when ordering the results.
        :param str parent_task: Foreign Key referenced by HREF
        :param list[str] reserved_resources_record:
        :param datetime started_at: ISO 8601 formatted dates are supported
        :param datetime started_at__gt: Filter results where started_at is greater than value
        :param datetime started_at__gte: Filter results where started_at is greater than or equal to value
        :param datetime started_at__lt: Filter results where started_at is less than value
        :param datetime started_at__lte: Filter results where started_at is less than or equal to value
        :param list[datetime] started_at__range: Filter results where started_at is between two comma separated values
        :param str state:
        :param list[str] state__in: Filter results where state is in a comma-separated list of values
        :param str task_group: Foreign Key referenced by HREF
        :param str worker: Foreign Key referenced by HREF
        :param list[str] worker__in: Filter results where worker is in a comma-separated list of values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedTaskResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(**kwargs)  # noqa: E501

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List tasks  # noqa: E501

        A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str child_tasks: Foreign Key referenced by HREF
        :param str created_resources:
        :param datetime finished_at: ISO 8601 formatted dates are supported
        :param datetime finished_at__gt: Filter results where finished_at is greater than value
        :param datetime finished_at__gte: Filter results where finished_at is greater than or equal to value
        :param datetime finished_at__lt: Filter results where finished_at is less than value
        :param datetime finished_at__lte: Filter results where finished_at is less than or equal to value
        :param list[datetime] finished_at__range: Filter results where finished_at is between two comma separated values
        :param int limit: Number of results to return per page.
        :param str logging_cid:
        :param str logging_cid__contains: Filter results where logging_cid contains value
        :param str name:
        :param str name__contains: Filter results where name contains value
        :param int offset: The initial index from which to return the results.
        :param str ordering: Which field to use when ordering the results.
        :param str parent_task: Foreign Key referenced by HREF
        :param list[str] reserved_resources_record:
        :param datetime started_at: ISO 8601 formatted dates are supported
        :param datetime started_at__gt: Filter results where started_at is greater than value
        :param datetime started_at__gte: Filter results where started_at is greater than or equal to value
        :param datetime started_at__lt: Filter results where started_at is less than value
        :param datetime started_at__lte: Filter results where started_at is less than or equal to value
        :param list[datetime] started_at__range: Filter results where started_at is between two comma separated values
        :param str state:
        :param list[str] state__in: Filter results where state is in a comma-separated list of values
        :param str task_group: Foreign Key referenced by HREF
        :param str worker: Foreign Key referenced by HREF
        :param list[str] worker__in: Filter results where worker is in a comma-separated list of values
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedTaskResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'child_tasks',
            'created_resources',
            'finished_at',
            'finished_at__gt',
            'finished_at__gte',
            'finished_at__lt',
            'finished_at__lte',
            'finished_at__range',
            'limit',
            'logging_cid',
            'logging_cid__contains',
            'name',
            'name__contains',
            'offset',
            'ordering',
            'parent_task',
            'reserved_resources_record',
            'started_at',
            'started_at__gt',
            'started_at__gte',
            'started_at__lt',
            'started_at__lte',
            'started_at__range',
            'state',
            'state__in',
            'task_group',
            'worker',
            'worker__in',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'child_tasks' in local_var_params and local_var_params['child_tasks'] is not None:  # noqa: E501
            query_params.append(('child_tasks', local_var_params['child_tasks']))  # noqa: E501
        if 'created_resources' in local_var_params and local_var_params['created_resources'] is not None:  # noqa: E501
            query_params.append(('created_resources', local_var_params['created_resources']))  # noqa: E501
        if 'finished_at' in local_var_params and local_var_params['finished_at'] is not None:  # noqa: E501
            query_params.append(('finished_at', local_var_params['finished_at']))  # noqa: E501
        if 'finished_at__gt' in local_var_params and local_var_params['finished_at__gt'] is not None:  # noqa: E501
            query_params.append(('finished_at__gt', local_var_params['finished_at__gt']))  # noqa: E501
        if 'finished_at__gte' in local_var_params and local_var_params['finished_at__gte'] is not None:  # noqa: E501
            query_params.append(('finished_at__gte', local_var_params['finished_at__gte']))  # noqa: E501
        if 'finished_at__lt' in local_var_params and local_var_params['finished_at__lt'] is not None:  # noqa: E501
            query_params.append(('finished_at__lt', local_var_params['finished_at__lt']))  # noqa: E501
        if 'finished_at__lte' in local_var_params and local_var_params['finished_at__lte'] is not None:  # noqa: E501
            query_params.append(('finished_at__lte', local_var_params['finished_at__lte']))  # noqa: E501
        if 'finished_at__range' in local_var_params and local_var_params['finished_at__range'] is not None:  # noqa: E501
            query_params.append(('finished_at__range', local_var_params['finished_at__range']))  # noqa: E501
            collection_formats['finished_at__range'] = 'csv'  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'logging_cid' in local_var_params and local_var_params['logging_cid'] is not None:  # noqa: E501
            query_params.append(('logging_cid', local_var_params['logging_cid']))  # noqa: E501
        if 'logging_cid__contains' in local_var_params and local_var_params['logging_cid__contains'] is not None:  # noqa: E501
            query_params.append(('logging_cid__contains', local_var_params['logging_cid__contains']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'name__contains' in local_var_params and local_var_params['name__contains'] is not None:  # noqa: E501
            query_params.append(('name__contains', local_var_params['name__contains']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'ordering' in local_var_params and local_var_params['ordering'] is not None:  # noqa: E501
            query_params.append(('ordering', local_var_params['ordering']))  # noqa: E501
        if 'parent_task' in local_var_params and local_var_params['parent_task'] is not None:  # noqa: E501
            query_params.append(('parent_task', local_var_params['parent_task']))  # noqa: E501
        if 'reserved_resources_record' in local_var_params and local_var_params['reserved_resources_record'] is not None:  # noqa: E501
            query_params.append(('reserved_resources_record', local_var_params['reserved_resources_record']))  # noqa: E501
            collection_formats['reserved_resources_record'] = 'multi'  # noqa: E501
        if 'started_at' in local_var_params and local_var_params['started_at'] is not None:  # noqa: E501
            query_params.append(('started_at', local_var_params['started_at']))  # noqa: E501
        if 'started_at__gt' in local_var_params and local_var_params['started_at__gt'] is not None:  # noqa: E501
            query_params.append(('started_at__gt', local_var_params['started_at__gt']))  # noqa: E501
        if 'started_at__gte' in local_var_params and local_var_params['started_at__gte'] is not None:  # noqa: E501
            query_params.append(('started_at__gte', local_var_params['started_at__gte']))  # noqa: E501
        if 'started_at__lt' in local_var_params and local_var_params['started_at__lt'] is not None:  # noqa: E501
            query_params.append(('started_at__lt', local_var_params['started_at__lt']))  # noqa: E501
        if 'started_at__lte' in local_var_params and local_var_params['started_at__lte'] is not None:  # noqa: E501
            query_params.append(('started_at__lte', local_var_params['started_at__lte']))  # noqa: E501
        if 'started_at__range' in local_var_params and local_var_params['started_at__range'] is not None:  # noqa: E501
            query_params.append(('started_at__range', local_var_params['started_at__range']))  # noqa: E501
            collection_formats['started_at__range'] = 'csv'  # noqa: E501
        if 'state' in local_var_params and local_var_params['state'] is not None:  # noqa: E501
            query_params.append(('state', local_var_params['state']))  # noqa: E501
        if 'state__in' in local_var_params and local_var_params['state__in'] is not None:  # noqa: E501
            query_params.append(('state__in', local_var_params['state__in']))  # noqa: E501
            collection_formats['state__in'] = 'csv'  # noqa: E501
        if 'task_group' in local_var_params and local_var_params['task_group'] is not None:  # noqa: E501
            query_params.append(('task_group', local_var_params['task_group']))  # noqa: E501
        if 'worker' in local_var_params and local_var_params['worker'] is not None:  # noqa: E501
            query_params.append(('worker', local_var_params['worker']))  # noqa: E501
        if 'worker__in' in local_var_params and local_var_params['worker__in'] is not None:  # noqa: E501
            query_params.append(('worker__in', local_var_params['worker__in']))  # noqa: E501
            collection_formats['worker__in'] = 'csv'  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/tasks/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedTaskResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, task_href, **kwargs):  # noqa: E501
        """Inspect a task  # noqa: E501

        A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(task_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_with_http_info(task_href, **kwargs)  # noqa: E501

    def read_with_http_info(self, task_href, **kwargs):  # noqa: E501
        """Inspect a task  # noqa: E501

        A customized named ModelViewSet that knows how to register itself with the Pulp API router.  This viewset is discoverable by its name. \"Normal\" Django Models and Master/Detail models are supported by the ``register_with`` method.  Attributes:     lookup_field (str): The name of the field by which an object should be looked up, in         addition to any parent lookups if this ViewSet is nested. Defaults to 'pk'     endpoint_name (str): The name of the final path segment that should identify the ViewSet's         collection endpoint.     nest_prefix (str): Optional prefix under which this ViewSet should be nested. This must         correspond to the \"parent_prefix\" of a router with rest_framework_nested.NestedMixin.         None indicates this ViewSet should not be nested.     parent_lookup_kwargs (dict): Optional mapping of key names that would appear in self.kwargs         to django model filter expressions that can be used with the corresponding value from         self.kwargs, used only by a nested ViewSet to filter based on the parent object's         identity.     schema (DefaultSchema): The schema class to use by default in a viewset.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(task_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_href',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_href' is set
        if self.api_client.client_side_validation and ('task_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_href` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_href' in local_var_params:
            path_params['task_href'] = local_var_params['task_href']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{task_href}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tasks_cancel(self, task_href, patched_task_cancel, **kwargs):  # noqa: E501
        """Cancel a task  # noqa: E501

        This operation cancels a task.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tasks_cancel(task_href, patched_task_cancel, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_href: (required)
        :param PatchedTaskCancel patched_task_cancel: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TaskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.tasks_cancel_with_http_info(task_href, patched_task_cancel, **kwargs)  # noqa: E501

    def tasks_cancel_with_http_info(self, task_href, patched_task_cancel, **kwargs):  # noqa: E501
        """Cancel a task  # noqa: E501

        This operation cancels a task.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tasks_cancel_with_http_info(task_href, patched_task_cancel, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str task_href: (required)
        :param PatchedTaskCancel patched_task_cancel: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TaskResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'task_href',
            'patched_task_cancel'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tasks_cancel" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'task_href' is set
        if self.api_client.client_side_validation and ('task_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['task_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `task_href` when calling `tasks_cancel`")  # noqa: E501
        # verify the required parameter 'patched_task_cancel' is set
        if self.api_client.client_side_validation and ('patched_task_cancel' not in local_var_params or  # noqa: E501
                                                        local_var_params['patched_task_cancel'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `patched_task_cancel` when calling `tasks_cancel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'task_href' in local_var_params:
            path_params['task_href'] = local_var_params['task_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'patched_task_cancel' in local_var_params:
            body_params = local_var_params['patched_task_cancel']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{task_href}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TaskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pulpcore.client.pulpcore.api_client import ApiClient
from pulpcore.client.pulpcore.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ContentguardsRbacApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def assign_permission(self, r_b_a_c_content_guard_href, rbac_content_guard_permission, **kwargs):  # noqa: E501
        """Add download permission  # noqa: E501

        Give users and groups the `download` permission  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_permission(r_b_a_c_content_guard_href, rbac_content_guard_permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param RBACContentGuardPermission rbac_content_guard_permission: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RBACContentGuardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.assign_permission_with_http_info(r_b_a_c_content_guard_href, rbac_content_guard_permission, **kwargs)  # noqa: E501

    def assign_permission_with_http_info(self, r_b_a_c_content_guard_href, rbac_content_guard_permission, **kwargs):  # noqa: E501
        """Add download permission  # noqa: E501

        Give users and groups the `download` permission  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_permission_with_http_info(r_b_a_c_content_guard_href, rbac_content_guard_permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param RBACContentGuardPermission rbac_content_guard_permission: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RBACContentGuardResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'r_b_a_c_content_guard_href',
            'rbac_content_guard_permission'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign_permission" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'r_b_a_c_content_guard_href' is set
        if self.api_client.client_side_validation and ('r_b_a_c_content_guard_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['r_b_a_c_content_guard_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `r_b_a_c_content_guard_href` when calling `assign_permission`")  # noqa: E501
        # verify the required parameter 'rbac_content_guard_permission' is set
        if self.api_client.client_side_validation and ('rbac_content_guard_permission' not in local_var_params or  # noqa: E501
                                                        local_var_params['rbac_content_guard_permission'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rbac_content_guard_permission` when calling `assign_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'r_b_a_c_content_guard_href' in local_var_params:
            path_params['r_b_a_c_content_guard_href'] = local_var_params['r_b_a_c_content_guard_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rbac_content_guard_permission' in local_var_params:
            body_params = local_var_params['rbac_content_guard_permission']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{r_b_a_c_content_guard_href}assign_permission/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RBACContentGuardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create(self, rbac_content_guard, **kwargs):  # noqa: E501
        """Create a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(rbac_content_guard, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RBACContentGuard rbac_content_guard: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RBACContentGuardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_with_http_info(rbac_content_guard, **kwargs)  # noqa: E501

    def create_with_http_info(self, rbac_content_guard, **kwargs):  # noqa: E501
        """Create a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(rbac_content_guard, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RBACContentGuard rbac_content_guard: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RBACContentGuardResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'rbac_content_guard'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'rbac_content_guard' is set
        if self.api_client.client_side_validation and ('rbac_content_guard' not in local_var_params or  # noqa: E501
                                                        local_var_params['rbac_content_guard'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rbac_content_guard` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rbac_content_guard' in local_var_params:
            body_params = local_var_params['rbac_content_guard']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/contentguards/core/rbac/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RBACContentGuardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete(self, r_b_a_c_content_guard_href, **kwargs):  # noqa: E501
        """Delete a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(r_b_a_c_content_guard_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_with_http_info(r_b_a_c_content_guard_href, **kwargs)  # noqa: E501

    def delete_with_http_info(self, r_b_a_c_content_guard_href, **kwargs):  # noqa: E501
        """Delete a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_with_http_info(r_b_a_c_content_guard_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'r_b_a_c_content_guard_href'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'r_b_a_c_content_guard_href' is set
        if self.api_client.client_side_validation and ('r_b_a_c_content_guard_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['r_b_a_c_content_guard_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `r_b_a_c_content_guard_href` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'r_b_a_c_content_guard_href' in local_var_params:
            path_params['r_b_a_c_content_guard_href'] = local_var_params['r_b_a_c_content_guard_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{r_b_a_c_content_guard_href}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list(self, **kwargs):  # noqa: E501
        """List rbac content guards  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Number of results to return per page.
        :param str name:
        :param str name__contains: Filter results where name contains value
        :param str name__icontains: Filter results where name contains value
        :param list[str] name__in: Filter results where name is in a comma-separated list of values
        :param str name__startswith: Filter results where name starts with value
        :param int offset: The initial index from which to return the results.
        :param str ordering: Which field to use when ordering the results.
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PaginatedRBACContentGuardResponseList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_with_http_info(**kwargs)  # noqa: E501

    def list_with_http_info(self, **kwargs):  # noqa: E501
        """List rbac content guards  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: Number of results to return per page.
        :param str name:
        :param str name__contains: Filter results where name contains value
        :param str name__icontains: Filter results where name contains value
        :param list[str] name__in: Filter results where name is in a comma-separated list of values
        :param str name__startswith: Filter results where name starts with value
        :param int offset: The initial index from which to return the results.
        :param str ordering: Which field to use when ordering the results.
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PaginatedRBACContentGuardResponseList, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'limit',
            'name',
            'name__contains',
            'name__icontains',
            'name__in',
            'name__startswith',
            'offset',
            'ordering',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'name__contains' in local_var_params and local_var_params['name__contains'] is not None:  # noqa: E501
            query_params.append(('name__contains', local_var_params['name__contains']))  # noqa: E501
        if 'name__icontains' in local_var_params and local_var_params['name__icontains'] is not None:  # noqa: E501
            query_params.append(('name__icontains', local_var_params['name__icontains']))  # noqa: E501
        if 'name__in' in local_var_params and local_var_params['name__in'] is not None:  # noqa: E501
            query_params.append(('name__in', local_var_params['name__in']))  # noqa: E501
            collection_formats['name__in'] = 'csv'  # noqa: E501
        if 'name__startswith' in local_var_params and local_var_params['name__startswith'] is not None:  # noqa: E501
            query_params.append(('name__startswith', local_var_params['name__startswith']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'ordering' in local_var_params and local_var_params['ordering'] is not None:  # noqa: E501
            query_params.append(('ordering', local_var_params['ordering']))  # noqa: E501
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '/pulp/api/v3/contentguards/core/rbac/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaginatedRBACContentGuardResponseList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def partial_update(self, r_b_a_c_content_guard_href, patched_rbac_content_guard, **kwargs):  # noqa: E501
        """Update a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.partial_update(r_b_a_c_content_guard_href, patched_rbac_content_guard, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param PatchedRBACContentGuard patched_rbac_content_guard: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RBACContentGuardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.partial_update_with_http_info(r_b_a_c_content_guard_href, patched_rbac_content_guard, **kwargs)  # noqa: E501

    def partial_update_with_http_info(self, r_b_a_c_content_guard_href, patched_rbac_content_guard, **kwargs):  # noqa: E501
        """Update a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.partial_update_with_http_info(r_b_a_c_content_guard_href, patched_rbac_content_guard, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param PatchedRBACContentGuard patched_rbac_content_guard: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RBACContentGuardResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'r_b_a_c_content_guard_href',
            'patched_rbac_content_guard'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method partial_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'r_b_a_c_content_guard_href' is set
        if self.api_client.client_side_validation and ('r_b_a_c_content_guard_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['r_b_a_c_content_guard_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `r_b_a_c_content_guard_href` when calling `partial_update`")  # noqa: E501
        # verify the required parameter 'patched_rbac_content_guard' is set
        if self.api_client.client_side_validation and ('patched_rbac_content_guard' not in local_var_params or  # noqa: E501
                                                        local_var_params['patched_rbac_content_guard'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `patched_rbac_content_guard` when calling `partial_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'r_b_a_c_content_guard_href' in local_var_params:
            path_params['r_b_a_c_content_guard_href'] = local_var_params['r_b_a_c_content_guard_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'patched_rbac_content_guard' in local_var_params:
            body_params = local_var_params['patched_rbac_content_guard']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{r_b_a_c_content_guard_href}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RBACContentGuardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, r_b_a_c_content_guard_href, **kwargs):  # noqa: E501
        """Inspect a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(r_b_a_c_content_guard_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RBACContentGuardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.read_with_http_info(r_b_a_c_content_guard_href, **kwargs)  # noqa: E501

    def read_with_http_info(self, r_b_a_c_content_guard_href, **kwargs):  # noqa: E501
        """Inspect a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(r_b_a_c_content_guard_href, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param str fields: A list of fields to include in the response.
        :param str exclude_fields: A list of fields to exclude from the response.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RBACContentGuardResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'r_b_a_c_content_guard_href',
            'fields',
            'exclude_fields'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'r_b_a_c_content_guard_href' is set
        if self.api_client.client_side_validation and ('r_b_a_c_content_guard_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['r_b_a_c_content_guard_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `r_b_a_c_content_guard_href` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'r_b_a_c_content_guard_href' in local_var_params:
            path_params['r_b_a_c_content_guard_href'] = local_var_params['r_b_a_c_content_guard_href']  # noqa: E501

        query_params = []
        if 'fields' in local_var_params and local_var_params['fields'] is not None:  # noqa: E501
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501
        if 'exclude_fields' in local_var_params and local_var_params['exclude_fields'] is not None:  # noqa: E501
            query_params.append(('exclude_fields', local_var_params['exclude_fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{r_b_a_c_content_guard_href}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RBACContentGuardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_permission(self, r_b_a_c_content_guard_href, rbac_content_guard_permission, **kwargs):  # noqa: E501
        """Remove download permission  # noqa: E501

        Remove `download` permission from users and groups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_permission(r_b_a_c_content_guard_href, rbac_content_guard_permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param RBACContentGuardPermission rbac_content_guard_permission: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RBACContentGuardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_permission_with_http_info(r_b_a_c_content_guard_href, rbac_content_guard_permission, **kwargs)  # noqa: E501

    def remove_permission_with_http_info(self, r_b_a_c_content_guard_href, rbac_content_guard_permission, **kwargs):  # noqa: E501
        """Remove download permission  # noqa: E501

        Remove `download` permission from users and groups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_permission_with_http_info(r_b_a_c_content_guard_href, rbac_content_guard_permission, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param RBACContentGuardPermission rbac_content_guard_permission: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RBACContentGuardResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'r_b_a_c_content_guard_href',
            'rbac_content_guard_permission'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_permission" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'r_b_a_c_content_guard_href' is set
        if self.api_client.client_side_validation and ('r_b_a_c_content_guard_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['r_b_a_c_content_guard_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `r_b_a_c_content_guard_href` when calling `remove_permission`")  # noqa: E501
        # verify the required parameter 'rbac_content_guard_permission' is set
        if self.api_client.client_side_validation and ('rbac_content_guard_permission' not in local_var_params or  # noqa: E501
                                                        local_var_params['rbac_content_guard_permission'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rbac_content_guard_permission` when calling `remove_permission`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'r_b_a_c_content_guard_href' in local_var_params:
            path_params['r_b_a_c_content_guard_href'] = local_var_params['r_b_a_c_content_guard_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rbac_content_guard_permission' in local_var_params:
            body_params = local_var_params['rbac_content_guard_permission']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{r_b_a_c_content_guard_href}remove_permission/', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RBACContentGuardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update(self, r_b_a_c_content_guard_href, rbac_content_guard, **kwargs):  # noqa: E501
        """Update a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update(r_b_a_c_content_guard_href, rbac_content_guard, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param RBACContentGuard rbac_content_guard: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: RBACContentGuardResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_with_http_info(r_b_a_c_content_guard_href, rbac_content_guard, **kwargs)  # noqa: E501

    def update_with_http_info(self, r_b_a_c_content_guard_href, rbac_content_guard, **kwargs):  # noqa: E501
        """Update a rbac content guard  # noqa: E501

        Viewset for creating contentguards that use RBAC to protect content. Has add and remove actions for managing permission for users and groups to download content protected by this guard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_with_http_info(r_b_a_c_content_guard_href, rbac_content_guard, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str r_b_a_c_content_guard_href: (required)
        :param RBACContentGuard rbac_content_guard: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(RBACContentGuardResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'r_b_a_c_content_guard_href',
            'rbac_content_guard'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'r_b_a_c_content_guard_href' is set
        if self.api_client.client_side_validation and ('r_b_a_c_content_guard_href' not in local_var_params or  # noqa: E501
                                                        local_var_params['r_b_a_c_content_guard_href'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `r_b_a_c_content_guard_href` when calling `update`")  # noqa: E501
        # verify the required parameter 'rbac_content_guard' is set
        if self.api_client.client_side_validation and ('rbac_content_guard' not in local_var_params or  # noqa: E501
                                                        local_var_params['rbac_content_guard'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rbac_content_guard` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'r_b_a_c_content_guard_href' in local_var_params:
            path_params['r_b_a_c_content_guard_href'] = local_var_params['r_b_a_c_content_guard_href']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rbac_content_guard' in local_var_params:
            body_params = local_var_params['rbac_content_guard']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'cookieAuth']  # noqa: E501

        return self.api_client.call_api(
            '{r_b_a_c_content_guard_href}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RBACContentGuardResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulpcore.configuration import Configuration


class UserResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'id': 'int',
        'username': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'is_staff': 'bool',
        'is_active': 'bool',
        'date_joined': 'datetime',
        'groups': 'list[UserGroupResponse]'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'id': 'id',
        'username': 'username',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'email': 'email',
        'is_staff': 'is_staff',
        'is_active': 'is_active',
        'date_joined': 'date_joined',
        'groups': 'groups'
    }

    def __init__(self, pulp_href=None, id=None, username=None, first_name=None, last_name=None, email=None, is_staff=False, is_active=True, date_joined=None, groups=None, local_vars_configuration=None):  # noqa: E501
        """UserResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._id = None
        self._username = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._is_staff = None
        self._is_active = None
        self._date_joined = None
        self._groups = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if id is not None:
            self.id = id
        self.username = username
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        if is_staff is not None:
            self.is_staff = is_staff
        if is_active is not None:
            self.is_active = is_active
        if date_joined is not None:
            self.date_joined = date_joined
        if groups is not None:
            self.groups = groups

    @property
    def pulp_href(self):
        """Gets the pulp_href of this UserResponse.  # noqa: E501


        :return: The pulp_href of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this UserResponse.


        :param pulp_href: The pulp_href of this UserResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def id(self):
        """Gets the id of this UserResponse.  # noqa: E501


        :return: The id of this UserResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserResponse.


        :param id: The id of this UserResponse.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def username(self):
        """Gets the username of this UserResponse.  # noqa: E501

        Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.  # noqa: E501

        :return: The username of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UserResponse.

        Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.  # noqa: E501

        :param username: The username of this UserResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and username is None:  # noqa: E501
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                username is not None and len(username) > 150):
            raise ValueError("Invalid value for `username`, length must be less than or equal to `150`")  # noqa: E501

        self._username = username

    @property
    def first_name(self):
        """Gets the first_name of this UserResponse.  # noqa: E501

        First name  # noqa: E501

        :return: The first_name of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this UserResponse.

        First name  # noqa: E501

        :param first_name: The first_name of this UserResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and first_name is None:  # noqa: E501
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                first_name is not None and len(first_name) > 150):
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `150`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this UserResponse.  # noqa: E501

        Last name  # noqa: E501

        :return: The last_name of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this UserResponse.

        Last name  # noqa: E501

        :param last_name: The last_name of this UserResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and last_name is None:  # noqa: E501
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                last_name is not None and len(last_name) > 150):
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `150`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this UserResponse.  # noqa: E501

        Email address  # noqa: E501

        :return: The email of this UserResponse.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserResponse.

        Email address  # noqa: E501

        :param email: The email of this UserResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def is_staff(self):
        """Gets the is_staff of this UserResponse.  # noqa: E501

        Designates whether the user can log into this admin site.  # noqa: E501

        :return: The is_staff of this UserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_staff

    @is_staff.setter
    def is_staff(self, is_staff):
        """Sets the is_staff of this UserResponse.

        Designates whether the user can log into this admin site.  # noqa: E501

        :param is_staff: The is_staff of this UserResponse.  # noqa: E501
        :type: bool
        """

        self._is_staff = is_staff

    @property
    def is_active(self):
        """Gets the is_active of this UserResponse.  # noqa: E501

        Designates whether this user should be treated as active.  # noqa: E501

        :return: The is_active of this UserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this UserResponse.

        Designates whether this user should be treated as active.  # noqa: E501

        :param is_active: The is_active of this UserResponse.  # noqa: E501
        :type: bool
        """

        self._is_active = is_active

    @property
    def date_joined(self):
        """Gets the date_joined of this UserResponse.  # noqa: E501

        Date joined  # noqa: E501

        :return: The date_joined of this UserResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_joined

    @date_joined.setter
    def date_joined(self, date_joined):
        """Sets the date_joined of this UserResponse.

        Date joined  # noqa: E501

        :param date_joined: The date_joined of this UserResponse.  # noqa: E501
        :type: datetime
        """

        self._date_joined = date_joined

    @property
    def groups(self):
        """Gets the groups of this UserResponse.  # noqa: E501


        :return: The groups of this UserResponse.  # noqa: E501
        :rtype: list[UserGroupResponse]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        """Sets the groups of this UserResponse.


        :param groups: The groups of this UserResponse.  # noqa: E501
        :type: list[UserGroupResponse]
        """

        self._groups = groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulpcore.configuration import Configuration


class StatusResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'versions': 'list[VersionResponse]',
        'online_workers': 'list[WorkerResponse]',
        'online_content_apps': 'list[ContentAppStatusResponse]',
        'database_connection': 'DatabaseConnectionResponse',
        'redis_connection': 'RedisConnectionResponse',
        'storage': 'StorageResponse'
    }

    attribute_map = {
        'versions': 'versions',
        'online_workers': 'online_workers',
        'online_content_apps': 'online_content_apps',
        'database_connection': 'database_connection',
        'redis_connection': 'redis_connection',
        'storage': 'storage'
    }

    def __init__(self, versions=None, online_workers=None, online_content_apps=None, database_connection=None, redis_connection=None, storage=None, local_vars_configuration=None):  # noqa: E501
        """StatusResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._versions = None
        self._online_workers = None
        self._online_content_apps = None
        self._database_connection = None
        self._redis_connection = None
        self._storage = None
        self.discriminator = None

        self.versions = versions
        self.online_workers = online_workers
        self.online_content_apps = online_content_apps
        self.database_connection = database_connection
        if redis_connection is not None:
            self.redis_connection = redis_connection
        if storage is not None:
            self.storage = storage

    @property
    def versions(self):
        """Gets the versions of this StatusResponse.  # noqa: E501

        Version information of Pulp components  # noqa: E501

        :return: The versions of this StatusResponse.  # noqa: E501
        :rtype: list[VersionResponse]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this StatusResponse.

        Version information of Pulp components  # noqa: E501

        :param versions: The versions of this StatusResponse.  # noqa: E501
        :type: list[VersionResponse]
        """
        if self.local_vars_configuration.client_side_validation and versions is None:  # noqa: E501
            raise ValueError("Invalid value for `versions`, must not be `None`")  # noqa: E501

        self._versions = versions

    @property
    def online_workers(self):
        """Gets the online_workers of this StatusResponse.  # noqa: E501

        List of online workers known to the application. An online worker is actively heartbeating and can respond to new work  # noqa: E501

        :return: The online_workers of this StatusResponse.  # noqa: E501
        :rtype: list[WorkerResponse]
        """
        return self._online_workers

    @online_workers.setter
    def online_workers(self, online_workers):
        """Sets the online_workers of this StatusResponse.

        List of online workers known to the application. An online worker is actively heartbeating and can respond to new work  # noqa: E501

        :param online_workers: The online_workers of this StatusResponse.  # noqa: E501
        :type: list[WorkerResponse]
        """
        if self.local_vars_configuration.client_side_validation and online_workers is None:  # noqa: E501
            raise ValueError("Invalid value for `online_workers`, must not be `None`")  # noqa: E501

        self._online_workers = online_workers

    @property
    def online_content_apps(self):
        """Gets the online_content_apps of this StatusResponse.  # noqa: E501

        List of online content apps known to the application. An online content app is actively heartbeating and can serve data to clients  # noqa: E501

        :return: The online_content_apps of this StatusResponse.  # noqa: E501
        :rtype: list[ContentAppStatusResponse]
        """
        return self._online_content_apps

    @online_content_apps.setter
    def online_content_apps(self, online_content_apps):
        """Sets the online_content_apps of this StatusResponse.

        List of online content apps known to the application. An online content app is actively heartbeating and can serve data to clients  # noqa: E501

        :param online_content_apps: The online_content_apps of this StatusResponse.  # noqa: E501
        :type: list[ContentAppStatusResponse]
        """
        if self.local_vars_configuration.client_side_validation and online_content_apps is None:  # noqa: E501
            raise ValueError("Invalid value for `online_content_apps`, must not be `None`")  # noqa: E501

        self._online_content_apps = online_content_apps

    @property
    def database_connection(self):
        """Gets the database_connection of this StatusResponse.  # noqa: E501

        Database connection information  # noqa: E501

        :return: The database_connection of this StatusResponse.  # noqa: E501
        :rtype: DatabaseConnectionResponse
        """
        return self._database_connection

    @database_connection.setter
    def database_connection(self, database_connection):
        """Sets the database_connection of this StatusResponse.

        Database connection information  # noqa: E501

        :param database_connection: The database_connection of this StatusResponse.  # noqa: E501
        :type: DatabaseConnectionResponse
        """
        if self.local_vars_configuration.client_side_validation and database_connection is None:  # noqa: E501
            raise ValueError("Invalid value for `database_connection`, must not be `None`")  # noqa: E501

        self._database_connection = database_connection

    @property
    def redis_connection(self):
        """Gets the redis_connection of this StatusResponse.  # noqa: E501

        Redis connection information  # noqa: E501

        :return: The redis_connection of this StatusResponse.  # noqa: E501
        :rtype: RedisConnectionResponse
        """
        return self._redis_connection

    @redis_connection.setter
    def redis_connection(self, redis_connection):
        """Sets the redis_connection of this StatusResponse.

        Redis connection information  # noqa: E501

        :param redis_connection: The redis_connection of this StatusResponse.  # noqa: E501
        :type: RedisConnectionResponse
        """

        self._redis_connection = redis_connection

    @property
    def storage(self):
        """Gets the storage of this StatusResponse.  # noqa: E501

        Storage information  # noqa: E501

        :return: The storage of this StatusResponse.  # noqa: E501
        :rtype: StorageResponse
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this StatusResponse.

        Storage information  # noqa: E501

        :param storage: The storage of this StatusResponse.  # noqa: E501
        :type: StorageResponse
        """

        self._storage = storage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StatusResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulpcore
from pulpcore.client.pulpcore.models.status_response import StatusResponse  # noqa: E501
from pulpcore.client.pulpcore.rest import ApiException

class TestStatusResponse(unittest.TestCase):
    """StatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatusResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulpcore.models.status_response.StatusResponse()  # noqa: E501
        if include_optional :
            return StatusResponse(
                versions = [
                    pulpcore.client.pulpcore.models.version_response.VersionResponse(
                        component = '0', 
                        version = '0', )
                    ], 
                online_workers = [
                    pulpcore.client.pulpcore.models.worker_response.WorkerResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ], 
                online_content_apps = [
                    pulpcore.client.pulpcore.models.content_app_status_response.ContentAppStatusResponse(
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ], 
                database_connection = null, 
                redis_connection = null, 
                storage = null
            )
        else :
            return StatusResponse(
                versions = [
                    pulpcore.client.pulpcore.models.version_response.VersionResponse(
                        component = '0', 
                        version = '0', )
                    ],
                online_workers = [
                    pulpcore.client.pulpcore.models.worker_response.WorkerResponse(
                        pulp_href = '0', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                online_content_apps = [
                    pulpcore.client.pulpcore.models.content_app_status_response.ContentAppStatusResponse(
                        name = '0', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                database_connection = null,
        )

    def testStatusResponse(self):
        """Test StatusResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.16.6"

# import apis into sdk package
from pulpcore.client.pulpcore.api.access_policies_api import AccessPoliciesApi
from pulpcore.client.pulpcore.api.artifacts_api import ArtifactsApi
from pulpcore.client.pulpcore.api.content_api import ContentApi
from pulpcore.client.pulpcore.api.contentguards_api import ContentguardsApi
from pulpcore.client.pulpcore.api.contentguards_rbac_api import ContentguardsRbacApi
from pulpcore.client.pulpcore.api.exporters_filesystem_api import ExportersFilesystemApi
from pulpcore.client.pulpcore.api.exporters_filesystem_exports_api import ExportersFilesystemExportsApi
from pulpcore.client.pulpcore.api.exporters_pulp_api import ExportersPulpApi
from pulpcore.client.pulpcore.api.exporters_pulp_exports_api import ExportersPulpExportsApi
from pulpcore.client.pulpcore.api.groups_api import GroupsApi
from pulpcore.client.pulpcore.api.groups_model_permissions_api import GroupsModelPermissionsApi
from pulpcore.client.pulpcore.api.groups_object_permissions_api import GroupsObjectPermissionsApi
from pulpcore.client.pulpcore.api.groups_users_api import GroupsUsersApi
from pulpcore.client.pulpcore.api.importers_pulp_api import ImportersPulpApi
from pulpcore.client.pulpcore.api.importers_pulp_import_check_api import ImportersPulpImportCheckApi
from pulpcore.client.pulpcore.api.importers_pulp_imports_api import ImportersPulpImportsApi
from pulpcore.client.pulpcore.api.orphans_api import OrphansApi
from pulpcore.client.pulpcore.api.orphans_cleanup_api import OrphansCleanupApi
from pulpcore.client.pulpcore.api.publications_api import PublicationsApi
from pulpcore.client.pulpcore.api.repair_api import RepairApi
from pulpcore.client.pulpcore.api.repositories_api import RepositoriesApi
from pulpcore.client.pulpcore.api.repositories_reclaim_space_api import RepositoriesReclaimSpaceApi
from pulpcore.client.pulpcore.api.repository_versions_api import RepositoryVersionsApi
from pulpcore.client.pulpcore.api.signing_services_api import SigningServicesApi
from pulpcore.client.pulpcore.api.status_api import StatusApi
from pulpcore.client.pulpcore.api.task_groups_api import TaskGroupsApi
from pulpcore.client.pulpcore.api.tasks_api import TasksApi
from pulpcore.client.pulpcore.api.uploads_api import UploadsApi
from pulpcore.client.pulpcore.api.users_api import UsersApi
from pulpcore.client.pulpcore.api.workers_api import WorkersApi

# import ApiClient
from pulpcore.client.pulpcore.api_client import ApiClient
from pulpcore.client.pulpcore.configuration import Configuration
from pulpcore.client.pulpcore.exceptions import OpenApiException
from pulpcore.client.pulpcore.exceptions import ApiTypeError
from pulpcore.client.pulpcore.exceptions import ApiValueError
from pulpcore.client.pulpcore.exceptions import ApiKeyError
from pulpcore.client.pulpcore.exceptions import ApiException
# import models into sdk package
from pulpcore.client.pulpcore.models.access_policy import AccessPolicy
from pulpcore.client.pulpcore.models.access_policy_response import AccessPolicyResponse
from pulpcore.client.pulpcore.models.artifact import Artifact
from pulpcore.client.pulpcore.models.artifact_response import ArtifactResponse
from pulpcore.client.pulpcore.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulpcore.models.content_app_status_response import ContentAppStatusResponse
from pulpcore.client.pulpcore.models.content_guard_response import ContentGuardResponse
from pulpcore.client.pulpcore.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulpcore.models.database_connection_response import DatabaseConnectionResponse
from pulpcore.client.pulpcore.models.evaluation_response import EvaluationResponse
from pulpcore.client.pulpcore.models.filesystem_export import FilesystemExport
from pulpcore.client.pulpcore.models.filesystem_export_response import FilesystemExportResponse
from pulpcore.client.pulpcore.models.filesystem_exporter import FilesystemExporter
from pulpcore.client.pulpcore.models.filesystem_exporter_response import FilesystemExporterResponse
from pulpcore.client.pulpcore.models.group import Group
from pulpcore.client.pulpcore.models.group_progress_report_response import GroupProgressReportResponse
from pulpcore.client.pulpcore.models.group_response import GroupResponse
from pulpcore.client.pulpcore.models.group_user import GroupUser
from pulpcore.client.pulpcore.models.group_user_response import GroupUserResponse
from pulpcore.client.pulpcore.models.import_response import ImportResponse
from pulpcore.client.pulpcore.models.method_enum import MethodEnum
from pulpcore.client.pulpcore.models.minimal_task_response import MinimalTaskResponse
from pulpcore.client.pulpcore.models.multiple_artifact_content_response import MultipleArtifactContentResponse
from pulpcore.client.pulpcore.models.orphans_cleanup import OrphansCleanup
from pulpcore.client.pulpcore.models.paginated_access_policy_response_list import PaginatedAccessPolicyResponseList
from pulpcore.client.pulpcore.models.paginated_artifact_response_list import PaginatedArtifactResponseList
from pulpcore.client.pulpcore.models.paginated_content_guard_response_list import PaginatedContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_filesystem_export_response_list import PaginatedFilesystemExportResponseList
from pulpcore.client.pulpcore.models.paginated_filesystem_exporter_response_list import PaginatedFilesystemExporterResponseList
from pulpcore.client.pulpcore.models.paginated_group_response_list import PaginatedGroupResponseList
from pulpcore.client.pulpcore.models.paginated_group_user_response_list import PaginatedGroupUserResponseList
from pulpcore.client.pulpcore.models.paginated_import_response_list import PaginatedImportResponseList
from pulpcore.client.pulpcore.models.paginated_multiple_artifact_content_response_list import PaginatedMultipleArtifactContentResponseList
from pulpcore.client.pulpcore.models.paginated_permission_response_list import PaginatedPermissionResponseList
from pulpcore.client.pulpcore.models.paginated_publication_response_list import PaginatedPublicationResponseList
from pulpcore.client.pulpcore.models.paginated_pulp_export_response_list import PaginatedPulpExportResponseList
from pulpcore.client.pulpcore.models.paginated_pulp_exporter_response_list import PaginatedPulpExporterResponseList
from pulpcore.client.pulpcore.models.paginated_pulp_importer_response_list import PaginatedPulpImporterResponseList
from pulpcore.client.pulpcore.models.paginated_rbac_content_guard_response_list import PaginatedRBACContentGuardResponseList
from pulpcore.client.pulpcore.models.paginated_repository_response_list import PaginatedRepositoryResponseList
from pulpcore.client.pulpcore.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulpcore.models.paginated_signing_service_response_list import PaginatedSigningServiceResponseList
from pulpcore.client.pulpcore.models.paginated_task_group_response_list import PaginatedTaskGroupResponseList
from pulpcore.client.pulpcore.models.paginated_task_response_list import PaginatedTaskResponseList
from pulpcore.client.pulpcore.models.paginated_upload_response_list import PaginatedUploadResponseList
from pulpcore.client.pulpcore.models.paginated_user_response_list import PaginatedUserResponseList
from pulpcore.client.pulpcore.models.paginated_worker_response_list import PaginatedWorkerResponseList
from pulpcore.client.pulpcore.models.patched_access_policy import PatchedAccessPolicy
from pulpcore.client.pulpcore.models.patched_filesystem_exporter import PatchedFilesystemExporter
from pulpcore.client.pulpcore.models.patched_group import PatchedGroup
from pulpcore.client.pulpcore.models.patched_pulp_exporter import PatchedPulpExporter
from pulpcore.client.pulpcore.models.patched_pulp_importer import PatchedPulpImporter
from pulpcore.client.pulpcore.models.patched_rbac_content_guard import PatchedRBACContentGuard
from pulpcore.client.pulpcore.models.patched_task_cancel import PatchedTaskCancel
from pulpcore.client.pulpcore.models.permission_response import PermissionResponse
from pulpcore.client.pulpcore.models.progress_report_response import ProgressReportResponse
from pulpcore.client.pulpcore.models.publication_response import PublicationResponse
from pulpcore.client.pulpcore.models.pulp_export import PulpExport
from pulpcore.client.pulpcore.models.pulp_export_response import PulpExportResponse
from pulpcore.client.pulpcore.models.pulp_exporter import PulpExporter
from pulpcore.client.pulpcore.models.pulp_exporter_response import PulpExporterResponse
from pulpcore.client.pulpcore.models.pulp_import import PulpImport
from pulpcore.client.pulpcore.models.pulp_import_check import PulpImportCheck
from pulpcore.client.pulpcore.models.pulp_import_check_response import PulpImportCheckResponse
from pulpcore.client.pulpcore.models.pulp_importer import PulpImporter
from pulpcore.client.pulpcore.models.pulp_importer_response import PulpImporterResponse
from pulpcore.client.pulpcore.models.rbac_content_guard import RBACContentGuard
from pulpcore.client.pulpcore.models.rbac_content_guard_permission import RBACContentGuardPermission
from pulpcore.client.pulpcore.models.rbac_content_guard_response import RBACContentGuardResponse
from pulpcore.client.pulpcore.models.reclaim_space import ReclaimSpace
from pulpcore.client.pulpcore.models.redis_connection_response import RedisConnectionResponse
from pulpcore.client.pulpcore.models.repair import Repair
from pulpcore.client.pulpcore.models.repository_response import RepositoryResponse
from pulpcore.client.pulpcore.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulpcore.models.signing_service_response import SigningServiceResponse
from pulpcore.client.pulpcore.models.status_response import StatusResponse
from pulpcore.client.pulpcore.models.storage_response import StorageResponse
from pulpcore.client.pulpcore.models.task_group_operation_response import TaskGroupOperationResponse
from pulpcore.client.pulpcore.models.task_group_response import TaskGroupResponse
from pulpcore.client.pulpcore.models.task_response import TaskResponse
from pulpcore.client.pulpcore.models.upload import Upload
from pulpcore.client.pulpcore.models.upload_chunk import UploadChunk
from pulpcore.client.pulpcore.models.upload_chunk_response import UploadChunkResponse
from pulpcore.client.pulpcore.models.upload_commit import UploadCommit
from pulpcore.client.pulpcore.models.upload_detail_response import UploadDetailResponse
from pulpcore.client.pulpcore.models.upload_response import UploadResponse
from pulpcore.client.pulpcore.models.user_group_response import UserGroupResponse
from pulpcore.client.pulpcore.models.user_response import UserResponse
from pulpcore.client.pulpcore.models.version_response import VersionResponse
from pulpcore.client.pulpcore.models.worker_response import WorkerResponse




# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulpcore
from pulpcore.client.pulpcore.models.upload import Upload  # noqa: E501
from pulpcore.client.pulpcore.rest import ApiException

class TestUpload(unittest.TestCase):
    """Upload unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Upload
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulpcore.models.upload.Upload()  # noqa: E501
        if include_optional :
            return Upload(
                size = 56
            )
        else :
            return Upload(
                size = 56,
        )

    def testUpload(self):
        """Test Upload"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
